@@ -1,7 +1,7 @@
 import json
 
 from django.core import serializers as django_serializers
-from django.forms import formset_factory
+from django.forms import formset_factory, inlineformset_factory
 from django.http import JsonResponse, HttpResponse, QueryDict
 from django.shortcuts import render, get_object_or_404
 from django.utils.decorators import method_decorator
@@ -389,9 +389,12 @@ class AccessoryViewSet(viewsets.ModelViewSet):
         accessory_form = AccessoryForm(instance=accessory)
         calibration_form = CalibrationForm(initial={'accessory': accessory})
 
+        datatransformerset = inlineformset_factory(DataTransformer, DataTransformer,form=DataTransform,formset=DataTransformerForm,
+                                                   fk_name='data_transformer_parent',
+                                                   extra=1, exclude=['updated_at', 'created_at'])
+
         if accessory.has_data_transformer:
             data_transformer = accessory.datatransformer
-            datatransformerset = formset_factory(DataTransform(instance=data_transformer), formset=DataTransformerForm, extra=0)
             formset = datatransformerset(instance=data_transformer)
         else:
             data_transformer = DataTransformer()
@@ -399,7 +402,6 @@ class AccessoryViewSet(viewsets.ModelViewSet):
             data_transformer.save()
             accessory = Accessory.objects.get(**kwargs)
             data_transformer = accessory.datatransformer
-            datatransformerset = formset_factory(DataTransform(instance=data_transformer), formset=DataTransformerForm, extra=0)
             formset = datatransformerset(instance=data_transformer)
 
         if request.accepted_renderer.format == 'html':
